@@ -330,36 +330,53 @@ setMethod("as.vector", "XString",
 ### The "show" method.
 ###
 
-### 'x' must be an XString or MaskedXString object.
+compact_ellipsis <- rawToChar(as.raw(c(0xe2, 0x80, 0xa6)))
+
+### NOT exported but used in the BSgenome package.
+### 'x' must be a single character string, or an XString or
+### MaskedXString object.
+### Return a character vector possibly with a class attribute on it for
+### later S3 dispatch in add_colors().
 toSeqSnippet <- function(x, width)
 {
     if (width < 7L)
         width <- 7L
-    seqlen <- length(x)
-    if (seqlen <= width) {
-        as.character(x)
+    ## Do NOT use nchar() here as it wouldn't do the right thing on a
+    ## MaskedXString object!
+    x_len <- length(x)
+    if (x_len <= width) {
+        ans <- as.character(x)
     } else {
-        w1 <- (width - 2) %/% 2
-        w2 <- (width - 3) %/% 2
-        paste(as.character(subseq(x, start=1, width=w1)),
-              "...",
-              as.character(subseq(x, end=seqlen, width=w2)),
-              sep="")
+        w1 <- (width - 2L) %/% 2L
+        w2 <- (width - 3L) %/% 2L
+        ans <- paste0(as.character(subseq(x, start=1, width=w1)),
+                      #compact_ellipsis,
+                      "...",
+                      as.character(subseq(x, end=x_len, width=w2)))
     }
+    if (is(x, "XString") || is(x, "MaskedXString"))
+        class(ans) <- c(seqtype(x), class(ans))  # for S3 dispatch
+                                                 # in add_colors()
+    ans
 }
 
 setMethod("show", "XString",
     function(object)
     {
-        lo <- object@length
-        cat("  ", lo, "-letter \"", class(object), "\" instance\n", sep="")
-        cat("seq:", toSeqSnippet(object, getOption("width") - 5))
-        cat("\n")
+        object_len <- object@length
+        cat(object_len, "-letter ", class(object), " object\n", sep="")
+        snippet <- toSeqSnippet(object, getOption("width") - 5L)
+        cat("seq: ", add_colors(snippet), "\n", sep="")
     }
 )
 
 setMethod("showAsCell", "XString",
-    function(object) safeExplode(as.character(object))
+    function(object)
+    {
+        ans <- safeExplode(as.character(object))
+        class(ans) <- c(seqtype(object), class(ans))
+        ans
+    }
 )
 
 
